@@ -10,13 +10,26 @@ typedef std::vector<Frame> Image;
 //void finalize_frame(Frame *frame);
 
 void finalize_image(Image *image);
-typedef Rcpp::XPtr<Image, Rcpp::PreserveStorage, finalize_image, true> XPtrImage;
+typedef Rcpp::XPtr<Image, Rcpp::PreserveStorage, finalize_image, false> XPtrImage;
 typedef Image::iterator Iter;
 
 XPtrImage create ();
 XPtrImage create (int len);
 XPtrImage copy (XPtrImage image);
 
+// Repage was introduced in 6.9.0-7 https://github.com/ImageMagick/ImageMagick/commit/919cb01
+#if MagickLibVersion >= 0x691
+#define myRepage() repage()
+#else
+#define myRepage() page(Magick::Geometry())
+#endif
+
+// Font utilities
+std::string normalize_font(const char * family);
+
+// Fuzz factor
+#define fuzz_pct_to_abs(x) ((x / 100 ) * (pow(MAGICKCORE_QUANTUM_DEPTH, 4) + 1))
+
 //IM 6~7 compatiblity
 #if MagickLibVersion >= 0x700
 Magick::Point Point(const char * str);
@@ -31,6 +44,7 @@ Magick::Point Point(const char * str);
 #define myGreenQ quantumGreen
 #define myBlueQ quantumBlue
 #define myAlphaQ quantumAlpha
+#define hasMatte() hasChannel(Magick::PixelChannel::AlphaPixelChannel)
 #else
 #define container list
 #define Point Geom
@@ -44,6 +58,7 @@ Magick::Point Point(const char * str);
 #define myGreenQ greenQuantum
 #define myBlueQ blueQuantum
 #define myAlphaQ alphaQuantum
+#define hasMatte() matte()
 #endif
 
 // Option parsers
